@@ -24,9 +24,11 @@ public:
     static QString defaultFiltersSettingsPath();
 
 private:
-    enum parseType { PartType = 0, ActionType = 1 };
+    enum parseType {
+        PartType = 0,
+        ActionType = 1,
+    };
     void parseFilters(const QDomElement &e);
     void parsePartAction(const QDomElement &ruleFilter, MailCommon::MailFilter *filter, MailCommon::FilterImporterEvolution::parseType type);
 };
 }
-
