@@ -5,11 +5,15 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_SOUNDTESTWIDGET_H
-#define MAILCOMMON_SOUNDTESTWIDGET_H
+#pragma once
 
 #include <QWidget>
 
+namespace Phonon
+{
+class MediaObject;
+}
+
 class QPushButton;
 class KUrlRequester;
 
@@ -67,9 +71,8 @@ private:
     void playSound();
     void openSoundDialog(KUrlRequester *);
     void slotUrlChanged(const QString &);
-    KUrlRequester *m_urlRequester = nullptr;
-    QPushButton *m_playButton = nullptr;
+    KUrlRequester *const m_urlRequester;
+    QPushButton *const m_playButton;
+    Phonon::MediaObject *m_player = nullptr;
 };
 }
-
-#endif
