@@ -4,32 +4,33 @@
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef MAILCOMMON_BACKUPJOB_H
-#define MAILCOMMON_BACKUPJOB_H
+#pragma once
 
 #include "mailcommon_export.h"
 
 #include <Libkdepim/ProgressManager>
 
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <QUrl>
 
+#include <QDateTime>
 #include <QObject>
 #include <QPointer>
-#include <QDateTime>
 
 class KArchive;
 class KJob;
 
 class QWidget;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ItemFetchJob;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * Writes an entire folder structure to an archive file. The archive is
  * structured like a hierarchy of maildir folders. However, every type of
@@ -43,15 +44,10 @@ class MAILCOMMON_EXPORT BackupJob : public QObject
 
 public:
     // These enum values have to stay in sync with the format combobox of ArchiveFolderDialog!
-    enum ArchiveType {
-        Zip = 0,
-        Tar = 1,
-        TarBz2 = 2,
-        TarGz = 3
-    };
+    enum ArchiveType { Zip = 0, Tar = 1, TarBz2 = 2, TarGz = 3 };
 
     explicit BackupJob(QWidget *parent = nullptr);
-    ~BackupJob();
+    ~BackupJob() override;
 
     void setRootFolder(const Akonadi::Collection &rootFolder);
     void setSaveLocation(const QUrl &savePath);
@@ -74,9 +70,9 @@ private:
     void archiveNextMessage();
     bool queueFolders(const Akonadi::Collection &root);
     void processMessage(const Akonadi::Item &item);
-    QString pathForCollection(const Akonadi::Collection &collection) const;
-    QString subdirPathForCollection(const Akonadi::Collection &collection) const;
-    bool hasChildren(const Akonadi::Collection &collection) const;
+    Q_REQUIRED_RESULT QString pathForCollection(const Akonadi::Collection &collection) const;
+    Q_REQUIRED_RESULT QString subdirPathForCollection(const Akonadi::Collection &collection) const;
+    Q_REQUIRED_RESULT bool hasChildren(const Akonadi::Collection &collection) const;
     void finish();
     void abort(const QString &errorMessage);
     bool writeDirHelper(const QString &directoryPath);
@@ -85,7 +81,7 @@ private:
     // Some Collection's don't have the name fetched. However, in mAllFolders,
     // we have a list of Collection's that have that information in them, so
     // we can just look it up there.
-    QString collectionName(const Akonadi::Collection &collection) const;
+    Q_REQUIRED_RESULT QString collectionName(const Akonadi::Collection &collection) const;
 
     QString mRealPath;
     QUrl mMailArchivePath;
@@ -109,5 +105,3 @@ private:
     bool mDisplayMessageBox = true;
 };
 }
-
-#endif
