@@ -11,6 +11,7 @@ using MailCommon::RuleWidgetHandlerManager;
 #include "mailcommon_debug.h"
 
 #include <KComboBox>
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <QButtonGroup>
@@ -21,43 +22,38 @@ using MailCommon::RuleWidgetHandlerManager;
 #include <QPushButton>
 #include <QRadioButton>
 #include <QStackedWidget>
-
 // Definition of special rule field strings
 // Note: Also see SearchRule::matches() and ruleFieldToEnglish() if
 //       you change the following i18n-ized strings!
 // Note: The index of the values in the following array has to correspond to
 //       the value of the entries in the enum in SearchRuleWidget.
 
-#undef I18N_NOOP
-#define I18N_NOOP(t) nullptr, t
-
 using namespace MailCommon;
 
 static const struct {
     const char *internalName;
-    const char *context;
-    const char *displayName;
+    const KLazyLocalizedString displayName;
 
-    QString getLocalizedDisplayName() const
+    Q_REQUIRED_RESULT QString getLocalizedDisplayName() const
     {
-        return i18nc(context, displayName);
+        return displayName.toString();
     }
-} SpecialRuleFields[] = {{"<message>", I18N_NOOP("Complete Message")},
-                         {"<body>", I18N_NOOP("Body of Message")},
-                         {"<any header>", I18N_NOOP("Anywhere in Headers")},
-                         {"<recipients>", I18N_NOOP("All Recipients")},
-                         {"<size>", I18N_NOOP("Size in Bytes")},
-                         {"<age in days>", I18N_NOOP("Age in Days")},
-                         {"<status>", I18N_NOOP("Message Status")},
-                         {"<tag>", I18N_NOOP("Message Tag")},
-                         {"Subject", I18NC_NOOP("Subject of an email.", "Subject")},
-                         {"From", I18N_NOOP("From")},
-                         {"To", I18NC_NOOP("Receiver of an email.", "To")},
-                         {"CC", I18N_NOOP("CC")},
-                         {"Reply-To", I18N_NOOP("Reply To")},
-                         {"Organization", I18N_NOOP("Organization")},
-                         {"<date>", I18N_NOOP("Date")},
-                         {"<encryption>", I18N_NOOP("Encryption")}};
+} SpecialRuleFields[] = {{"<message>", kli18n("Complete Message")},
+                         {"<body>", kli18n("Body of Message")},
+                         {"<any header>", kli18n("Anywhere in Headers")},
+                         {"<recipients>", kli18n("All Recipients")},
+                         {"<size>", kli18n("Size in Bytes")},
+                         {"<age in days>", kli18n("Age in Days")},
+                         {"<status>", kli18n("Message Status")},
+                         {"<tag>", kli18n("Message Tag")},
+                         {"Subject", kli18n("Subject")},
+                         {"From", kli18n("From")},
+                         {"To", kli18n("To")},
+                         {"CC", kli18n("CC")},
+                         {"Reply-To", kli18n("Reply To")},
+                         {"Organization", kli18n("Organization")},
+                         {"<date>", kli18n("Date")},
+                         {"<encryption>", kli18n("Encryption")}};
 static const int SpecialRuleFieldsCount = sizeof(SpecialRuleFields) / sizeof(*SpecialRuleFields);
 
 //=============================================================================
@@ -360,14 +356,14 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
     if (!notShowTags) {
         mFilterFieldList.append(SpecialRuleFields[Tag].getLocalizedDisplayName());
     }
-    mFilterFieldList.append(i18n(SpecialRuleFields[ReplyTo].displayName));
-    mFilterFieldList.append(i18n(SpecialRuleFields[Organization].displayName));
+    mFilterFieldList.append(SpecialRuleFields[ReplyTo].getLocalizedDisplayName());
+    mFilterFieldList.append(SpecialRuleFields[Organization].getLocalizedDisplayName());
 
     if (!notShowDate) {
-        mFilterFieldList.append(i18n(SpecialRuleFields[Date].displayName));
+        mFilterFieldList.append(SpecialRuleFields[Date].getLocalizedDisplayName());
     }
 
-    mFilterFieldList.append(i18n(SpecialRuleFields[Encryption].displayName));
+    mFilterFieldList.append(SpecialRuleFields[Encryption].getLocalizedDisplayName());
 
     // these others only represent message headers and you can add to
     // them as you like
@@ -399,9 +395,7 @@ SearchRuleWidgetLister::SearchRuleWidgetLister(QWidget *parent, SearchPatternEdi
     mOptions = options;
 }
 
-SearchRuleWidgetLister::~SearchRuleWidgetLister()
-{
-}
+SearchRuleWidgetLister::~SearchRuleWidgetLister() = default;
 
 void SearchRuleWidgetLister::setPatternEditOptions(SearchPatternEdit::SearchPatternEditOptions options)
 {
@@ -564,9 +558,7 @@ SearchPatternEdit::SearchPatternEdit(QWidget *parent, SearchPatternEditOptions o
     initLayout(options, modeType);
 }
 
-SearchPatternEdit::~SearchPatternEdit()
-{
-}
+SearchPatternEdit::~SearchPatternEdit() = default;
 
 void SearchPatternEdit::updateSearchPattern()
 {
