@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEXTRULERWIDGETHANDLER_H
-#define TEXTRULERWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
@@ -19,9 +18,7 @@ public:
     {
     }
 
-    ~TextRuleWidgetHandler() override
-    {
-    }
+    ~TextRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -46,4 +43,3 @@ private:
     QString currentValue(const QStackedWidget *valueStack, SearchRule::Function func) const;
 };
 }
-#endif // TEXTRULERWIDGETHANDLER_H
