@@ -4,14 +4,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_MAILUTIL_P_H
-#define MAILCOMMON_MAILUTIL_P_H
+#pragma once
 
 #include "mailcommon_export.h"
 #include "mailutil.h"
 
-#include <AgentInstance>
-#include <Collection>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/Collection>
 
 namespace MailCommon
 {
@@ -24,5 +23,3 @@ namespace Util
 Q_REQUIRED_RESULT bool ignoreNewMailInFolder(const Akonadi::Collection &collection);
 }
 }
-
-#endif
